@@ -1,9 +1,10 @@
-from typing import Optional
+from typing import List, Optional
 
 import click
 
 from contxt.cli.clients import Clients
-from contxt.cli.utils import OPTIONAL_PROMPT_KWARGS, print_item, print_table
+from contxt.cli.utils import OPTIONAL_PROMPT_KWARGS, fields_option, print_item, print_table, sort_option
+from contxt.models.contxt import ServiceInstance
 
 
 @click.group()
@@ -14,14 +15,16 @@ def service_instances() -> None:
 @service_instances.command()
 @click.option("--service-id")
 @click.pass_obj
-def get(clients: Clients, service_id: Optional[str]) -> None:
+@fields_option(default=["id", "slug", "service_id", "description"], obj=ServiceInstance)
+@sort_option(default="slug")
+def get(clients: Clients, service_id: Optional[str], fields: List[str], sort: str) -> None:
     """Get service instance(s)"""
     items = (
         clients.contxt_deployments.get(f"{clients.org_id}/services/{service_id}/service_instances")
         if service_id
         else clients.contxt_deployments.get(f"{clients.org_id}/service_instances")
     )
-    print_table(items, keys=["id", "slug", "service_id", "description"])
+    print_table(items, keys=fields, sort_by=sort)
 
 
 @service_instances.command()
@@ -35,7 +38,7 @@ def get(clients: Clients, service_id: Optional[str]) -> None:
 def create(
     clients: Clients,
     service_id: str,
-    project_environment_id: str,
+    project_environment_id: Optional[str],
     name: str,
     slug: str,
     descriptor: str,
