@@ -71,6 +71,7 @@ class Api:
         # Initialize session
         self.session = Session()
         self.session.auth = BearerTokenAuth(token_provider) if token_provider else None
+        self.session.headers.update({"Cache-Control": "no-cache"})
         self.session.hooks = {"response": self._log_response}  # type: ignore
 
         # Attach retry adapter
@@ -98,7 +99,7 @@ class Api:
             # Try to decode the response as json, else fall back to raw text
             response_json = self._get_json(response)
             msg = response_json.get("message") or response_json or response.text
-            logger.error(f"HTTP Error: {response.reason} - {msg}")
+            logger.debug(f"HTTP Error: {response.reason} - {msg}")
             raise
 
         # Return json, if any
